CardReference class final

Indirectly refers to a card by its set and order in that set.

Example

import 'package:unlimited/cards.dart';

final vader = CardReference(
  CardSet.sparkOfRebellion,
  10,
  name: 'Darth Vader',
  x: 1,
);
Annotations
  • @immutable

Constructors

CardReference(CardSet cardSet, int orderInSet, [int quantity = 1])
Creates a new CardReference with the given cardSet and orderInSet.

Properties

cardSet → CardSet
The set that this card belongs to.
final
hashCode → int
The hash code for this object.
no setteroverride
orderInSet → int
The order of this card in the set.
final
quantity → int
The number of copies of this card.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override