BaseCard class final

A base card.

Inheritance
Implemented types
Available extensions
Annotations
  • @immutable

Constructors

BaseCard({required CardSet cardSet, required int orderInSet, required String name, required Set<Aspect> aspects, required String location, int health = 30})
Creates a base card with the given properties.

Properties

aspects → Set<Aspect>
Aspects that the card belongs to.
finalinherited
cardSet → CardSet
The set the card belongs to.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
health → int
The health of the base.
final
location → String
The location of the base.
final
name → String
The name of the card.
finalinherited
orderInSet → int
Within the set, the card's number from 1 to CardSet.totalCards.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique → bool
Whether the card is unique.
finalinherited

Methods

duplicate(int count) → Iterable<T>

Available on T, provided by the CardDuplicator extension

Returns an iterable that yields this card count times.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
Returns a string representation of this object, suitable for debugging.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited