PlayableCard class sealed

A card that can be played, i.e. anything but a BaseCard.

Most of these cards can be included in a deck, except TokenCard.

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

aspects → Set<Aspect>
Aspects that the card belongs to.
finalinherited
cardSet → CardSet
The set the card belongs to.
finalinherited
cost → int
The cost of the card.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the card.
finalinherited
orderInSet → int
Within the set, the card's number from 1 to CardSet.totalCards.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traits → Set<Trait>
Traits that the card has.
final
unique → bool
Whether the card is unique.
finalinherited

Methods

duplicate(int count) → Iterable<T>

Available on T, provided by the CardDuplicator extension

Returns an iterable that yields this card count times.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
Returns a string representation of this object, suitable for debugging.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited