UpgradeCard class final

An upgrade card.

Inheritance
Available extensions

Constructors

UpgradeCard({required CardSet cardSet, required int orderInSet, required String name, required Set<Aspect> aspects, required int cost, required Set<Trait> traits, bool unique = false, int bonusPower = 0, int bonusHp = 0})
Creates an upgrade card with the given properties.

Properties

aspects → Set<Aspect>
Aspects that the card belongs to.
finalinherited
bonusHp → int
Amount of health added to a unit.
finalinherited
bonusPower → int
Amount of power added to a unit.
finalinherited
cardSet → CardSet
The set the card belongs to.
finalinherited
cost → int
The cost of the card.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the card.
finalinherited
orderInSet → int
Within the set, the card's number from 1 to CardSet.totalCards.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traits → Set<Trait>
Traits that the card has.
finalinherited
unique → bool
Whether the card is unique.
finalinherited

Methods

duplicate(int count) → Iterable<T>

Available on T, provided by the CardDuplicator extension

Returns an iterable that yields this card count times.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
Returns a string representation of this object, suitable for debugging.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited