DeployedBase class final

A deployed BaseCard.

Inheritance

Constructors

DeployedBase({required BaseCard card, int damage = 0})
Creates a deployed base with the given properties.
factory

Properties

card → BaseCard
Details (i.e. the card) about the unit.
finalinherited
damage → int
Amount of damage this unit has taken.
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
health → int
How much health the unit has left.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
Returns a string representation of this object, suitable for debugging.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override