DeployedUnit class final

A deployed UnitCard.

Inheritance

Constructors

DeployedUnit({required UnitCard card, int damage = 0, bool exhausted = false, List<UpgradeCard> upgrades = const []})
Creates a deployed unit with the given properties.
factory

Properties

card → UnitCard
Details (i.e. the card) about the unit.
finalinherited
damage → int
Amount of damage this unit has taken.
finalinherited
exhausted → bool
Whether the unit is exhausted.
final
hashCode → int
The hash code for this object.
no setteroverride
health → int
How much health the unit has left.
no setterinherited
ready → bool
Whether the unit is ready.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upgrades → List<UpgradeCard>
Upgrades attached to the unit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
Returns a string representation of this object, suitable for debugging.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override